Graphical User Interface
========================

PyMedPhys ships with a graphical user interface (GUI). To start the GUI call
the following within a terminal or command prompt:

.. code:: bash

    pymedphys gui

Streamlit
---------

The GUI is powered by `Streamlit <https://streamlit.io>`__. Streamlit is
relatively new and is undergoing rapid development. Therefore each PyMedPhys
version, for the time being, will pin to a specific Streamlit version. This
version restriction will be removed once the Streamlit APIs used by PyMedPhys
stabilise.


.. toctree::
    :maxdepth: 1

    metersetmap
    pseudonymisation
